Skip to contents

Choose or (temporarily) use the banc autosegmentation

Usage

choose_banc(set = TRUE)

with_banc(expr)

Arguments

set

Whether or not to permanently set the banc autosegmentation as the default for fafbseg-package functions.

expr

An expression to evaluate while banc is the default autosegmentation

Value

If set=TRUE a list containing the previous values of the relevant global options (in the style of options. If set=FALSE a named list containing the option values.

Details

bancr inherits a significant amount of infrastructure from the fafbseg-package package. This has the concept of the active autosegmentation, which in turn defines one or more R options containing URIs pointing to voxel-wise segmentation, mesh etc data. These are normally contained within a single neuroglancer URL which points to multiple data layers. For banc this is the neuroglancer scene returned by banc_scene.

Examples

if (FALSE) { # \dontrun{
choose_banc()
options()[grep("^fafbseg.*url", names(options()))]
} # }
if (FALSE) { # \dontrun{
with_banc(fafbseg::flywire_islatest('648518346498254576'))
} # }
if (FALSE) { # \dontrun{
with_banc(fafbseg::flywire_latestid('648518346498254576'))
with_banc(fafbseg::flywire_latestid('648518346494405175'))
} # }